@@ -6,7 +6,7 @@ use FindBin;
 
 package App::GUI::Harmonograph;
 our $NAME = __PACKAGE__;
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
 use base qw/Wx::App/;
 use App::GUI::Harmonograph::Frame;
@@ -277,6 +277,12 @@ submenu for setting the image size.
 The third menu has some dialogs with documentation and additional information.
 
 
+=head1 SEE ALSO
+
+L<App::GUI::Cellgraph>
+
+L<App::GUI::Dynagraph>
+
 =head1 AUTHOR
 
 Herbert Breunung (lichtkind@cpan.org)
